# -*- coding: utf-8 -*-

from __future__ import absolute_import
from .TextAnalysisCat import *
 
__version__ = '1.0.0'
__license__ = ''